define(["require", "exports"], function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var DataContext = (function () {
        function DataContext(sharedContext) {
            this.subscriptionQuotaUsage = ko.observable();
            this.proxyRequestLevel = ko.observable(1);
            this.selectedBillingPeriod = ko.observable();
            this.sharedContext = sharedContext;
        }
        DataContext.prototype.refreshBillingOverviews = function () {
            throw new Error("Not implemented");
        };
        DataContext.prototype.getPersonData = function () {
            return [{
                    "ssnId": 111,
                    "name": "Fred",
                    "bills": {
                        "paid": 5,
                        "overdue": 7
                    },
                    "birthday": "1983-12-14T00:00:00-08:00",
                    "smartPhone": "iPhone 5",
                    "location": {
                        "latitude": 41.85,
                        "longitude": -87.65
                    },
                    "onVacation": true,
                    "pairsOfShoes": 0,
                    "children": [],
                    "region": "United States"
                }, {
                    "ssnId": 222,
                    "name": "Bob",
                    "bills": {
                        "paid": 2,
                        "overdue": 1
                    },
                    "birthday": "1983-01-03T00:00:00-08:00",
                    "smartPhone": "Nexus 5",
                    "location": {
                        "latitude": 57.62,
                        "longitude": -122.35
                    },
                    "onVacation": false,
                    "pairsOfShoes": 4,
                    "children": [
                        111
                    ],
                    "region": "Canada"
                }, {
                    "ssnId": 333,
                    "name": "John",
                    "bills": {
                        "paid": 4,
                        "overdue": 3
                    },
                    "birthday": "1988-01-09T00:00:00-08:00",
                    "smartPhone": "Lumia 520",
                    "location": {
                        "latitude": 31.2,
                        "longitude": 121.5
                    },
                    "onVacation": false,
                    "pairsOfShoes": 3,
                    "children": [],
                    "region": "France"
                }, {
                    "ssnId": 444,
                    "name": "Alice",
                    "bills": {
                        "paid": 2,
                        "overdue": 0
                    },
                    "birthday": "1993-08-09T00:00:00-07:00",
                    "smartPhone": "Lumia 520",
                    "location": {
                        "latitude": 48.0,
                        "longitude": 11.0
                    },
                    "onVacation": true,
                    "pairsOfShoes": 2,
                    "children": [
                        222,
                        333
                    ],
                    "region": "Italy"
                }];
        };
        DataContext.prototype.getSampleInvoicesData = function () {
            return [{
                    "id": 111,
                    "billingPeriod": "January",
                    "totalAmount": 40,
                }, {
                    "id": 222,
                    "billingPeriod": "February",
                    "totalAmount": 62,
                }, {
                    "id": 333,
                    "billingPeriod": "March",
                    "totalAmount": 81,
                }, {
                    "id": 444,
                    "billingPeriod": "April",
                    "totalAmount": 81,
                }, {
                    "id": 555,
                    "billingPeriod": "May",
                    "totalAmount": 39,
                }, {
                    "id": 666,
                    "billingPeriod": "June",
                    "totalAmount": 42,
                }];
        };
        DataContext.prototype.getSampleInvoiceLineItemsData = function () {
            return [{
                    "id": 111,
                    "name": "CPU Cores",
                    "amount": 23.50,
                }, {
                    "id": 222,
                    "name": "RAM (MB)",
                    "amount": 42.00,
                }, {
                    "id": 333,
                    "name": "Internet Data (MB)",
                    "amount": 10.50,
                }, {
                    "id": 444,
                    "name": "SSD",
                    "amount": 7.00,
                }];
        };
        DataContext.prototype.getSampleMeteredResources = function (subscriptionId) {
            return [
                {
                    Id: 111,
                    Name: "CPU Cores",
                },
                {
                    Id: 222,
                    Name: "Memory",
                },
                {
                    Id: 333,
                    Name: "SSD",
                }
            ];
        };
        DataContext.prototype.getSampleUsageByResourceData = function (subscriptionId) {
            return [
                {
                    "SubscriptionId": subscriptionId,
                    "MeteredResourceId": 111,
                    "MeteredResourceName": "CPU Cores",
                    "ConsumedUnits": 23.50,
                    "Units": "Cores",
                    "IncludedUnitCredits": 10.0,
                    "Cost": this.getFormattedCost(13.50 * 0.1),
                    "Currency": "USD",
                },
                {
                    "SubscriptionId": subscriptionId,
                    "MeteredResourceId": 222,
                    "MeteredResourceName": "Memory",
                    "ConsumedUnits": 16,
                    "Units": "GB",
                    "IncludedUnitCredits": 4,
                    "Cost": this.getFormattedCost(12 * 0.05),
                    "Currency": "USD",
                },
                {
                    "SubscriptionId": subscriptionId,
                    "MeteredResourceId": 333,
                    "MeteredResourceName": "SSD",
                    "ConsumedUnits": 180,
                    "Units": "GB",
                    "IncludedUnitCredits": 40,
                    "Cost": this.getFormattedCost(140 * 0.005),
                    "Currency": "USD",
                },
            ];
        };
        DataContext.prototype.getFormattedCost = function (c) {
            return Number(+c.toFixed(2));
        };
        return DataContext;
    }());
    exports.DataContext = DataContext;
});
