var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
define(["require", "exports", "../../Shared/Helpers"], function (require, exports, Helpers) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var FxDropDown = MsPortalFx.ViewModels.Obsolete.Forms.DropDown;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var ArmHelpers = Common.Helpers;
    var CloudServiceSubscriptionsBladeViewModel = (function (_super) {
        __extends(CloudServiceSubscriptionsBladeViewModel, _super);
        function CloudServiceSubscriptionsBladeViewModel(container, initialState, dataContext) {
            var _this = _super.call(this) || this;
            _this._lastSelectedSubscriptionId = "";
            _this.subscriptionId = ko.observable();
            _this.cspEnabledSubscriptionIds = ko.observable();
            _this.location = ko.observable("local");
            _this.title("Cloud Subscriptions");
            _this._container = container;
            _this._dataContext = dataContext;
            _this.bladeConfiguration = container.activateConfiguration();
            _this._dataQueryView = dataContext.cspDataManager.cspSubscriptionsQuery.createView(container, {
                interceptNotFound: false
            });
            var subscriptionDropDownOptions = {
                label: ko.observable("Azure Stack Subscription Id"),
                infoBalloonContent: ko.observable("Choose the Azure Stack Subscription Id for listing Cloud Subscriptions"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            _this.subscriptionsDropDown = new FxDropDown.ViewModel(container, subscriptionDropDownOptions);
            _this.subscriptionsDropDown.value.subscribe(container, function (newSubscriptionId) {
                _this.subscriptionId(newSubscriptionId);
                _this.bladeConfiguration.updateValues({
                    settings: {
                        subscriptionId: newSubscriptionId
                    }
                });
            });
            var gridExtensions = FxGridExtensions.SelectableRow | FxGridExtensions.Filterable;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                },
                selectableRow: {
                    selectionMode: 1,
                }
            };
            _this.cloudServiceSubscriptionsGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "Id",
                    name: ko.observable("Cloud Subscription Id"),
                },
                {
                    itemKey: "FriendlyName",
                    name: ko.observable("Name"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "Quantity",
                    name: ko.observable("Quantity"),
                },
                {
                    itemKey: "Status",
                    name: ko.observable("Status"),
                    format: MsPortalFx.ViewModels.Controls.Lists.Grid.Format.SvgIconLookup,
                    formatOptions: {
                        svgIconLookup: {
                            "Active": {
                                svg: MsPortalFx.Base.Images.StatusBadge.Success(),
                                text: ko.observable("Active"),
                            },
                            "Suspended": {
                                svg: MsPortalFx.Base.Images.StatusBadge.Warning(),
                                text: ko.observable("Suspended"),
                            }
                        }
                    }
                },
            ];
            _this.cloudServiceSubscriptionsGrid.columns = ko.observableArray(basicColumns);
            _this.cloudServiceSubscriptionsGrid.showHeader = true;
            _this.cloudServiceSubscriptionsGrid.summary = ko.observable("Summary");
            _this.cloudServiceSubscriptionsGrid.noRowsMessage("No items found");
            _this.cloudServiceSubscriptionsGrid.selectableData.selectedItems.subscribe(container, function (selectedItems) {
                if (!selectedItems || selectedItems.length === 0) {
                    return;
                }
            });
            _this._dataQueryView.items.subscribe(container, function (cspSubs) {
                _this.cloudServiceSubscriptionsGrid.items(cspSubs);
            });
            _this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.cloudServiceSubscriptionsGrid.loading(isLoading);
            });
            _this._setupCommandBar();
            return _this;
        }
        CloudServiceSubscriptionsBladeViewModel.prototype._setupCommandBar = function () {
            this._refreshButton = this._createRefreshButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([this._refreshButton]);
        };
        CloudServiceSubscriptionsBladeViewModel.prototype._createRefreshButton = function () {
            var _this = this;
            var refreshButton = new FxToolbars.CommandButton({
                label: "Refresh",
                icon: MsPortalFx.Base.Images.Refresh(),
                command: {
                    canExecute: ko.observable(true),
                    execute: function (result) {
                        var q = _this._dataContext.cspDataManager.getSubscriptionListForCustomer(_this.cspEnabledSubscriptionIds()).then(function (items) {
                            _this.subscriptionId(items.first().WapSubscriptionId);
                            _this.cloudServiceSubscriptionsGrid.items(items);
                        });
                        return q;
                    }
                }
            });
            return refreshButton;
        };
        CloudServiceSubscriptionsBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            this.subtitle(inputs.cloudServiceUserId);
            return this._dataContext.sharedContext.subscriptionsManager.subscriptionsPromise.then(function (subscriptions) {
                var subscriptionId = "-";
                if (subscriptions.length > 0)
                    var subIds = subscriptions.map(function (s) { return s.subscriptionId; });
                _this._dataContext.cspDataManager.getCspEnabledSubIds(subIds).then(function (subscriptionsIds) {
                    _this.cspEnabledSubscriptionIds(subscriptionsIds);
                    _this._dataContext.cspDataManager.getSubscriptionListForCustomer(subscriptionsIds).then(function (items) {
                        _this.subscriptionId(items.first().WapSubscriptionId);
                        _this.cloudServiceSubscriptionsGrid.items(items);
                    });
                });
            });
        };
        CloudServiceSubscriptionsBladeViewModel.prototype._updateSubscriptionsDropdown = function (subscriptions) {
            var dropdownValues = subscriptions.map(function (s) {
                return {
                    text: ko.observable(s.uniqueDisplayName),
                    value: s.subscriptionId,
                    disabled: ko.observable(false)
                };
            });
            dropdownValues.unshift({
                text: ko.observable("Select a Azure Stack subscription..."),
                value: "-",
                disabled: ko.observable(false)
            });
            this.subscriptionsDropDown.options(dropdownValues);
            this.subscriptionsDropDown.value(this._lastSelectedSubscriptionId || "-");
        };
        return CloudServiceSubscriptionsBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CloudServiceSubscriptionsBladeViewModel = CloudServiceSubscriptionsBladeViewModel;
});
