define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var ArmConstants = Common.Constants;
    var ArmHelpers = Common.Helpers;
    var rpApiVersion = window.fx.environment.billingRpApiVersion;
    "use strict";
    var CspDataManager = (function () {
        function CspDataManager() {
            this.cspSubscriptionsQuery = new MsPortalFx.Data.QueryCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._cspSubsQueryRelativeUriFormat, rpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
            this.cspUsersQuery = new MsPortalFx.Data.QueryCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._cspUsersQueryRelativeUriFormat, rpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
            this.cspOffersQuery = new MsPortalFx.Data.QueryCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._cspOffersQueryRelativeUriFormat, rpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
            this.cspSubscriptionEntity = new MsPortalFx.Data.EntityCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._cspSubsEntityRelativeUriFormat, rpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
            this.cspCustomerProfilesQuery = new MsPortalFx.Data.QueryCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._cspCustomerProfilesQueryRelativeUriFormat, rpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
            this.cspCustomersQuery = new MsPortalFx.Data.QueryCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._cspCustomersQueryRelativeUriFormat, rpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
        }
        CspDataManager.prototype.purchaseCloudServiceLicense = function (subscriptionId, cspOffer, quantity, cspEnabledSubscriptions) {
            var argsToUri = {
                cspOfferId: cspOffer.Id,
                subscriptionId: subscriptionId,
                location: "local"
            };
            var purchaseUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspOffers/{cspOfferId}/purchase";
            var uriSegment = MsPortalFx.Data.uriFormatter(purchaseUriFormat, false)(argsToUri);
            var lineItem = {
                LineItemNumber: 0,
                FriendlyName: cspOffer.Name,
                OfferId: cspOffer.Id,
                PartnerIdOnRecord: "",
                Quantity: quantity,
            };
            var CspOrderIn = {
                ReferenceCustomerId: "",
                LineItems: [lineItem],
                ParentSubscriptionId: "",
                IsAddOn: false,
                WapUserId: ""
            };
            var postData = JSON.stringify({
                CspOrderIn: CspOrderIn,
                CspEnabledSubscriptions: cspEnabledSubscriptions
            });
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully purchased Cloud Service Offer",
                    description: "Success"
                },
                inProgress: {
                    title: "Purchasing Cloud Service Offer...",
                    description: "..."
                },
                error: {
                    title: "Failure purchasing Cloud Service Offer",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Cloud Service Offer");
            return promise;
        };
        CspDataManager.prototype.addCspUser = function (subscriptionId, cspCustomerUser) {
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: "local"
            };
            var createCspUserUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/cspCustomerUsers/createCspCustomerUser";
            var uriSegment = MsPortalFx.Data.uriFormatter(createCspUserUriFormat, false)(argsToUri);
            var postData = JSON.stringify(cspCustomerUser);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully added Cloud Service User",
                    description: "Success"
                },
                inProgress: {
                    title: "Adding Cloud Service User...",
                    description: "..."
                },
                error: {
                    title: "Failure adding the Cloud Service User",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Cloud Service User");
            return promise;
        };
        CspDataManager.prototype.purchaseMoreLicenses = function (subscriptionId, cspSubscriptionId, newQuantity, cspEnabledSubscriptions) {
            var argsToUri = {
                subscriptionId: subscriptionId,
                cspSubscriptionId: cspSubscriptionId,
                location: "local"
            };
            var purchaseUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspSubscriptions/{cspSubscriptionId}/purchaseMoreLicenses";
            var uriSegment = MsPortalFx.Data.uriFormatter(purchaseUriFormat, false)(argsToUri);
            var cspSubscriptionIn = {
                Id: cspSubscriptionId,
                Quantity: newQuantity,
            };
            var postData = JSON.stringify({
                CspSubscriptionIn: cspSubscriptionIn,
                CspEnabledSubscriptions: cspEnabledSubscriptions
            });
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully purchased more licenses",
                    description: "Success"
                },
                inProgress: {
                    title: "Purchasing more licenses...",
                    description: "..."
                },
                error: {
                    title: "Failure purchasing more licenses",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Cloud Service Offer");
            return promise;
        };
        CspDataManager.prototype.createCspCustomerProfile = function (subscriptionId, customerProfile) {
            var createCustomerProfile = MsPortalFx.Data.uriFormatter(CspDataManager._createCspCustomerProfileUriFormat, false)({
                subscriptionId: subscriptionId,
                location: 'local',
            });
            var postData = ko.toJSON(customerProfile);
            var promise = Helpers.callArm(createCustomerProfile, "POST", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully created customer profile",
                    description: "Please refresh the portal."
                },
                inProgress: {
                    title: "creating customer profile",
                    description: "..."
                },
                error: {
                    title: "Failure creating customer profile",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Cloud Service - Customer Profile");
            return promise;
        };
        CspDataManager.prototype.onboardExistingCspCustomerProfile = function (subscriptionId, customerProfile) {
            var createCustomerProfile = MsPortalFx.Data.uriFormatter(CspDataManager._onboardExistingCspCustomerProfileUriFormat, false)({
                subscriptionId: subscriptionId,
                location: 'local',
            });
            var postData = ko.toJSON(customerProfile);
            var promise = Helpers.callArm(createCustomerProfile, "POST", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully Onboarded customer.",
                    description: "Please refresh the portal."
                },
                inProgress: {
                    title: "Onboarding customer",
                    description: "..."
                },
                error: {
                    title: "Failure onboarding customer",
                    description: "Error : {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Cloud Service - Customer Profile");
            return promise;
        };
        CspDataManager.prototype.getCspMarketDetails = function (subscriptionId) {
            var uri = MsPortalFx.Data.uriFormatter(CspDataManager._getCspMarketDetailsUriFormat, false)({
                subscriptionId: subscriptionId,
                location: 'local'
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise;
        };
        CspDataManager.prototype.getCspCustomersForSubscriptionList = function (stackSubscriptionsList) {
            var argsToUri = {
                subscriptionId: stackSubscriptionsList[0],
                location: "local"
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(CspDataManager._cspCustomersQueryRelativeUriFormat, false)(argsToUri);
            var postData = ko.toJSON(stackSubscriptionsList);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        CspDataManager.prototype.getCspEnabledSubIds = function (subscriptionIdList) {
            var argsToUri = {
                subscriptionId: subscriptionIdList[0],
                location: "local"
            };
            var uri = MsPortalFx.Data.uriFormatter(CspDataManager._getCspEnabledQuotasUriFormat, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIdList);
            var promise = Helpers.callArm(uri, "POST", rpApiVersion, postData);
            return promise;
        };
        CspDataManager.prototype.getCspOverviewEssentials = function (subscriptionIdList) {
            var argsToUri = {
                subscriptionId: subscriptionIdList[0],
                location: "local"
            };
            var uri = MsPortalFx.Data.uriFormatter(CspDataManager._cspOverviewEssentialsQueryRelativeUriFormat, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIdList);
            var promise = Helpers.callArm(uri, "POST", rpApiVersion, postData);
            return promise;
        };
        CspDataManager.prototype.getCspCustomerUserLicensesDetails = function (subscriptionId, customerTenantId, customerUserId) {
            var uri = MsPortalFx.Data.uriFormatter(CspDataManager._getCspCustomerUserLicensesDetailsUriFormat, false)({
                subscriptionId: subscriptionId,
                customerTenantId: customerTenantId,
                customerUserId: customerUserId,
                location: 'local'
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise;
        };
        CspDataManager.prototype.getSubscriptionListForCustomer = function (subscriptionIdList) {
            var argsToUri = {
                subscriptionId: subscriptionIdList[0],
                location: "local"
            };
            var uri = MsPortalFx.Data.uriFormatter(CspDataManager._cspSubsQueryRelativeUriFormat, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIdList);
            var promise = Helpers.callArm(uri, "POST", rpApiVersion, postData);
            return promise;
        };
        CspDataManager.prototype.assignLicensesToCustomerUser = function (subscriptionId, customerTenantId, customerUserId, cspLicenseIn) {
            var argsToUri = {
                subscriptionId: subscriptionId,
                customerTenantId: customerTenantId,
                customerUserId: customerUserId,
                location: 'local'
            };
            var uri = MsPortalFx.Data.uriFormatter(CspDataManager._assignLicensesToCustomerUserUriFormat, false)(argsToUri);
            var postData = ko.toJSON(cspLicenseIn);
            var promise = Helpers.callArm(uri, "POST", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully associated cloud service licenses",
                    description: "Success"
                },
                inProgress: {
                    title: "Associating cloud service licenses...",
                    description: "..."
                },
                error: {
                    title: "Failure associating cloud service licenses",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Cloud Service Licenses");
            return promise;
        };
        return CspDataManager;
    }());
    CspDataManager._cspSubsQueryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspSubscriptions";
    CspDataManager._cspUsersQueryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspCustomerUsers";
    CspDataManager._cspOffersQueryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/CspOffers";
    CspDataManager._cspCustomerProfilesQueryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspCustomerProfiles";
    CspDataManager._cspCustomersQueryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/getCspCustomersForSubscriptionList";
    CspDataManager._cspOverviewEssentialsQueryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/getCspOverviewEssentials";
    CspDataManager._cspSubsEntityRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspSubscriptions/{cspSubscriptionId}";
    CspDataManager._createCspCustomerProfileUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/createCspCustomerProfile";
    CspDataManager._onboardExistingCspCustomerProfileUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/onboardExistingCspCustomerProfile";
    CspDataManager._getCspMarketDetailsUriFormat = "subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspMarketDetails";
    CspDataManager._getCspEnabledQuotasUriFormat = "subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspEnabledSubscriptions";
    CspDataManager._getCspCustomerUserLicensesDetailsUriFormat = "subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/cspCustomerUserLicenses/customerTenantId/{customerTenantId}/customerUserId/{customerUserId}";
    CspDataManager._assignLicensesToCustomerUserUriFormat = "subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/Csp/assignLicenses/customerTenantId/{customerTenantId}/customerUserId/{customerUserId}";
    CspDataManager._tenantGetVmTemplateParamDefUriFormat = "/subscriptions/{0}/providers/CloudAssert.Billing/locations/{1}/cspOffers/{2}";
    CspDataManager._publishToGalleryUriViaArmFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/cspOffers/publishToGallery";
    CspDataManager._publishToGalleryUriFormat = "/subscriptions/{0}/providers/CloudAssert.Billing.Admin/locations/{1}/cspOffers/publishToGallery";
    exports.CspDataManager = CspDataManager;
});
