define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var DataModels = BillingExtension.CustomDataModel;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var rpApiVersion = window.fx.environment.billingRpApiVersion;
    "use strict";
    var InvoicesManager = (function () {
        function InvoicesManager() {
            this.Urls = {
                invoicingHistoryForUser: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/listInvoicingHistoryForUser",
                payInvoiceViaStripe: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/PayInvoiceViaStripe",
                getStripePublishableKey: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/GetStripePublishableAPIKey",
                getBillingTenantUrl: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/GetBillingTenantUrl",
                payInvoiceViaStripeWithCreditCard: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/PayInvoiceViaStripeWithCreditCard",
                invoicesForSubscriptions: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/invoices",
                invoicesForSubscription: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/{invoiceId}",
                shouldShowPayInvoiceButton: "subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/ShouldShowPayInvoiceButton",
                markInvoiceAsInProgress: "subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/{invoiceId}/MarkInvoiceAsInProgress",
            };
            this.invoicesQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices", fxEnv.billingRpApiVersion);
            this.invoiceEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/{invoiceId}", fxEnv.billingRpApiVersion);
            this.downloadInvoiceUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/{invoiceId}/DownloadPdf", fxEnv.billingRpApiVersion);
            this.payInvoiceUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/{invoiceId}/Pay", fxEnv.billingRpApiVersion);
            this.downloadUsageCsvUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/invoices/0/DownloadUsageHistory", fxEnv.billingRpApiVersion);
            this.invoicesQuery = new MsPortalFx.Data.QueryCache({
                entityTypeName: DataModels.InvoiceModelType,
                sourceUri: this.invoicesQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.invoiceEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.InvoiceModelType,
                sourceUri: this.invoiceEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
        }
        InvoicesManager.prototype.getInvoicingHistoryForUser = function (subscriptionId) {
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.invoicingHistoryForUser, false)({
                subscriptionId: subscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + rpApiVersion;
            var q = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return q;
        };
        InvoicesManager.prototype.payInvoiceViaStripe = function (subscriptionId, paymentDetails) {
            var argsToUri = {
                subscriptionId: subscriptionId,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.payInvoiceViaStripe, false)(argsToUri);
            var postData = ko.toJSON(paymentDetails);
            var q = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully Paid Invoice",
                    description: "Success"
                },
                inProgress: {
                    title: "Payment of Invoice Inprogress...",
                    description: "..."
                },
                error: {
                    title: "Failure Invoice Payment",
                    description: "{resourceName} : Request Failed - {errorMsg}"
                }
            };
            Helpers.trackOperation(q, notificationSettings, "Pay Invoice");
            return q;
        };
        InvoicesManager.prototype.getStripePublishableAPIKey = function (subscriptionId) {
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.getStripePublishableKey, false)({
                subscriptionId: subscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + rpApiVersion;
            var q = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return q;
        };
        InvoicesManager.prototype.getBillingTenantExtUrl = function (subscriptionId) {
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.getBillingTenantUrl, false)({
                subscriptionId: subscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + rpApiVersion;
            var q = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return q;
        };
        InvoicesManager.prototype.shouldShowPayInvoiceButton = function (subscriptionId) {
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.shouldShowPayInvoiceButton, false)({
                subscriptionId: subscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + rpApiVersion;
            var q = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return q;
        };
        InvoicesManager.prototype.payInvoiceViaStripeWithCreditCardQuery = function (subscriptionId, cardIn) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.payInvoiceViaStripeWithCreditCard, false)(argsToUri);
            var postData = ko.toJSON(cardIn);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully Paid Invoice",
                    description: "Success"
                },
                inProgress: {
                    title: "Payment of Invoice Inprogress...",
                    description: "..."
                },
                error: {
                    title: "Failure linking Base Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Pay Invoice");
            return promise.then(function () {
                return _this.invoicesQuery.refreshAll();
            });
        };
        InvoicesManager.prototype.getInvoicesForSubscriptions = function (subscriptionId, subscriptionIds) {
            var argsToUri = {
                subscriptionId: subscriptionId,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.invoicesForSubscriptions, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIds);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        InvoicesManager.prototype.getInvoicesForSubscription = function (subscriptionId, subscriptionIds, invoiceId) {
            var argsToUri = {
                subscriptionId: subscriptionId,
                invoiceId: invoiceId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.invoicesForSubscription, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIds);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        InvoicesManager.prototype.markInvoiceStatusAsInProgress = function (subscriptionId, invoiceId) {
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.markInvoiceAsInProgress, false)({
                subscriptionId: subscriptionId,
                invoiceId: invoiceId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise;
        };
        return InvoicesManager;
    }());
    exports.InvoicesManager = InvoicesManager;
});
