define(["require", "exports"], function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var ArmHelpers = Common.Helpers;
    "use strict";
    var SubscriptionsManager = (function () {
        function SubscriptionsManager() {
            var _this = this;
            this.subscriptionIdList = [];
            this.subscriptionsPromise = this.getSubscriptionsForRp('CloudAssert.Billing');
            this.subscriptionsPromise.then(function (subscriptions) {
                subscriptions.forEach(function (subscription) {
                    _this.subscriptionIdList.push(subscription.subscriptionId);
                });
            });
        }
        SubscriptionsManager.prototype.getSubscriptionsForRp = function (rpNamespace) {
            var deferred = Q.defer();
            var subscriptionsResult = [];
            MsPortalFx.Azure.getAllSubscriptions().then(function (subscriptions) {
                var promises = [];
                subscriptions.forEach(function (subscription) {
                    var urlSegment = MsPortalFx.Data.uriFormatter('subscriptions/{subscriptionId}/providers', false)({
                        subscriptionId: subscription.subscriptionId,
                    });
                    var urlSegmentWithApiVersion = urlSegment + "?api-version=" + window.fx.environment.armApiVersion;
                    var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET").then(function (providersResponse) {
                        var providers = providersResponse.value;
                        var billingRp = providers.first(function (p) { return p.namespace === rpNamespace; });
                        if (billingRp && billingRp.registrationState === "Registered") {
                            subscriptionsResult.push(subscription);
                        }
                    });
                    promises.push(promise);
                });
                return Q.all(promises).then(function () {
                    deferred.resolve(subscriptionsResult);
                }, function (reason) {
                    deferred.reject(reason);
                });
            });
            return deferred.promise;
        };
        SubscriptionsManager.prototype.getSubscriptionAndOfferDetails = function (subscriptionId) {
            var deferred = Q.defer();
            var urlSegment = MsPortalFx.Data.uriFormatter('subscriptions/{subscriptionId}', false)({
                subscriptionId: subscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + window.fx.environment.armApiVersion + '&includeDetails=true';
            ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET").then(function (subDetails) {
                console.log(subDetails);
                var urlSegment1 = MsPortalFx.Data.uriFormatter('offers', false)({
                    subscriptionId: subscriptionId,
                });
                var urlSegmentWithApiVersion1 = urlSegment1 + "?api-version=" + window.fx.environment.armApiVersion;
                return ArmHelpers.callArmUri(urlSegmentWithApiVersion1, "GET").then(function (offers) {
                    var offersArray = offers.value;
                    var offer = offersArray.first(function (o) { return o.id === subDetails.offerId; });
                    var subOfferDetails = $.extend({}, {
                        SubscriptionId: subDetails.subscriptionId,
                        SubscriptionState: subDetails.state,
                        SubscriptionDisplayName: subDetails.displayName,
                        OfferId: offer.name,
                        OfferDisplayName: offer.displayName,
                    });
                    console.log('Subscription\'s Offer Details: ', subOfferDetails);
                    deferred.resolve(subOfferDetails);
                }, function (reason) {
                    deferred.reject(reason);
                });
            }, function (reason) {
                deferred.reject(reason);
            });
            return deferred.promise;
        };
        SubscriptionsManager.prototype.getQuotasForSubscription = function (subscriptionId) {
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: "local"
            };
            var uriSegment = MsPortalFx.Data.uriFormatter("subscriptions/{subscriptionId}/providers/CloudAssert.Billing/locations/{location}/quotas/ListQuotaSettings", false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + window.fx.environment.billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise;
        };
        return SubscriptionsManager;
    }());
    exports.SubscriptionsManager = SubscriptionsManager;
});
